#[module]Expand description
Marks a struct as an RHDL module shell for Story 1.1.
Generates Elaboratable that records directed ports via the builder session.
#[module]Marks a struct as an RHDL module shell for Story 1.1.
Generates Elaboratable that records directed ports via the builder session.